@@ -51,6 +51,7 @@ static EvBackendInfo *
 get_backend_info_for_mime_type (const gchar *mime_type)
 {
         GList *l;
+        gchar *content_type = g_content_type_from_mime_type (mime_type);
 
         for (l = ev_backends_list; l; l = l->next) {
                 EvBackendInfo *info = (EvBackendInfo *) l->data;
@@ -58,11 +59,14 @@ get_backend_info_for_mime_type (const gchar *mime_type)
                 guint i;
 
                 for (i = 0; mime_types[i] != NULL; ++i) {
-                        if (g_content_type_is_mime_type (mime_type, mime_types[i]))
+                        if (g_content_type_is_mime_type (content_type, mime_types[i])) {
+                                g_free (content_type);
                                 return info;
+                        }
                 }
         }
 
+        g_free (content_type);
         return NULL;
 }
 
